==> antd-4.3.3.jar: META-INF/resources/webjars/antd/4.3.3/lib/locale/fi_FI.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _fi_FI = _interopRequireDefault(require("rc-pagination/lib/locale/fi_FI"));

var _fi_FI2 = _interopRequireDefault(require("../date-picker/locale/fi_FI"));

var _fi_FI3 = _interopRequireDefault(require("../time-picker/locale/fi_FI"));

var _fi_FI4 = _interopRequireDefault(require("../calendar/locale/fi_FI"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var localeValues = {
  locale: 'fi',
  Pagination: _fi_FI["default"],
  DatePicker: _fi_FI2["default"],
  TimePicker: _fi_FI3["default"],
  Calendar: _fi_FI4["default"],
  Table: {
    filterTitle: 'Suodatus valikko',
    filterConfirm: 'OK',
    filterReset: 'Tyhjennä',
    selectAll: 'Valitse kaikki',
    selectInvert: 'Valitse päinvastoin',
    sortTitle: 'Lajittele'
  },
  Modal: {
    okText: 'OK',
    cancelText: 'Peruuta',
    justOkText: 'OK'
  },
  Popconfirm: {
    okText: 'OK',
    cancelText: 'Peruuta'
  },
  Transfer: {
    searchPlaceholder: 'Etsi täältä',
    itemUnit: 'kohde',
    itemsUnit: 'kohdetta'
  },
  Upload: {
    uploading: 'Lähetetään...',
    removeFile: 'Poista tiedosto',
    uploadError: 'Virhe lähetyksessä',
    previewFile: 'Esikatsele tiedostoa',
    downloadFile: 'Lataa tiedosto'
  },
  Empty: {
    description: 'Ei kohteita'
  },
  Text: {
    edit: 'Muokkaa',
    copy: 'Kopioi',
    copied: 'Kopioitu',
    expand: 'Näytä lisää'
  }
};
var _default = localeValues;
exports["default"] = _default;

==> antd-4.9.1.jar: META-INF/resources/webjars/antd/4.9.1/lib/locale/fi_FI.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _fi_FI = _interopRequireDefault(require("rc-pagination/lib/locale/fi_FI"));

var _fi_FI2 = _interopRequireDefault(require("../date-picker/locale/fi_FI"));

var _fi_FI3 = _interopRequireDefault(require("../time-picker/locale/fi_FI"));

var _fi_FI4 = _interopRequireDefault(require("../calendar/locale/fi_FI"));

var localeValues = {
  locale: 'fi',
  Pagination: _fi_FI["default"],
  DatePicker: _fi_FI2["default"],
  TimePicker: _fi_FI3["default"],
  Calendar: _fi_FI4["default"],
  Table: {
    filterTitle: 'Suodatus valikko',
    filterConfirm: 'OK',
    filterReset: 'Tyhjennä',
    selectAll: 'Valitse kaikki',
    selectInvert: 'Valitse päinvastoin',
    sortTitle: 'Lajittele'
  },
  Modal: {
    okText: 'OK',
    cancelText: 'Peruuta',
    justOkText: 'OK'
  },
  Popconfirm: {
    okText: 'OK',
    cancelText: 'Peruuta'
  },
  Transfer: {
    searchPlaceholder: 'Etsi täältä',
    itemUnit: 'kohde',
    itemsUnit: 'kohdetta'
  },
  Upload: {
    uploading: 'Lähetetään...',
    removeFile: 'Poista tiedosto',
    uploadError: 'Virhe lähetyksessä',
    previewFile: 'Esikatsele tiedostoa',
    downloadFile: 'Lataa tiedosto'
  },
  Empty: {
    description: 'Ei kohteita'
  },
  Text: {
    edit: 'Muokkaa',
    copy: 'Kopioi',
    copied: 'Kopioitu',
    expand: 'Näytä lisää'
  }
};
var _default = localeValues;
exports["default"] = _default;
